@@ -26,7 +26,7 @@ static void	add_instruct(PInfo pi, const char *name, Attr attrs, const char *con
 
 extern ParseCallbacks   ox_obj_callbacks;
 
-struct _ParseCallbacks   _ox_gen_callbacks = {
+struct _parseCallbacks   _ox_gen_callbacks = {
     instruct, /* instruct, */
     add_doctype,
     add_comment,
@@ -39,7 +39,7 @@ struct _ParseCallbacks   _ox_gen_callbacks = {
 
 ParseCallbacks   ox_gen_callbacks = &_ox_gen_callbacks;
 
-struct _ParseCallbacks   _ox_limited_callbacks = {
+struct _parseCallbacks   _ox_limited_callbacks = {
     0,
     0,
     0,
@@ -52,7 +52,7 @@ struct _ParseCallbacks   _ox_limited_callbacks = {
 
 ParseCallbacks   ox_limited_callbacks = &_ox_limited_callbacks;
 
-struct _ParseCallbacks   _ox_nomode_callbacks = {
+struct _parseCallbacks   _ox_nomode_callbacks = {
     nomode_instruct,
     add_doctype,
     add_comment,
@@ -90,7 +90,7 @@ create_prolog_doc(PInfo pi, const char *target, Attr attrs) {
     volatile VALUE	sym;
 
     if (!helper_stack_empty(&pi->helpers)) { /* top level object */
-        ox_err_set(&pi->err, rb_eSyntaxError, "Prolog must be the first element in an XML document.\n");
+        ox_err_set(&pi->err, ox_syntax_error_class, "Prolog must be the first element in an XML document.\n");
 	return;
     }
     doc = rb_obj_alloc(ox_document_clas);
@@ -161,7 +161,7 @@ instruct(PInfo pi, const char *target, Attr attrs, const char *content) {
         for (; 0 != attrs->name; attrs++) {
             if (0 == strcmp("version", attrs->name)) {
                 if (0 != strcmp("1.0", attrs->value)) {
-                    ox_err_set(&pi->err, rb_eSyntaxError, "Only Ox XML Object version 1.0 supported, not %s.\n", attrs->value);
+                    ox_err_set(&pi->err, ox_syntax_error_class, "Only Ox XML Object version 1.0 supported, not %s.\n", attrs->value);
 		    return;
                 }
             }
@@ -180,7 +180,7 @@ nomode_instruct(PInfo pi, const char *target, Attr attrs, const char *content) {
         for (; 0 != attrs->name; attrs++) {
             if (0 == strcmp("version", attrs->name)) {
                 if (0 != strcmp("1.0", attrs->value)) {
-                    ox_err_set(&pi->err, rb_eSyntaxError, "Only Ox XML Object version 1.0 supported, not %s.\n", attrs->value);
+                    ox_err_set(&pi->err, ox_syntax_error_class, "Only Ox XML Object version 1.0 supported, not %s.\n", attrs->value);
 		    return;
                 }
             } else if (0 == strcmp("mode", attrs->name)) {
@@ -195,7 +195,7 @@ nomode_instruct(PInfo pi, const char *target, Attr attrs, const char *content) {
                     pi->obj = Qnil;
 		    helper_stack_init(&pi->helpers);
                 } else {
-                    ox_err_set(&pi->err, rb_eSyntaxError, "%s is not a valid processing instruction mode.\n", attrs->value);
+                    ox_err_set(&pi->err, ox_syntax_error_class, "%s is not a valid processing instruction mode.\n", attrs->value);
 		    return;
                 }
             }
@@ -310,7 +310,7 @@ add_element(PInfo pi, const char *ename, Attr attrs, int hasChildren) {
     rb_ivar_set(e, ox_at_value_id, s);
     if (0 != attrs->name) {
         volatile VALUE	ah = rb_hash_new();
-        
+
         for (; 0 != attrs->name; attrs++) {
             volatile VALUE	sym;
 
@@ -424,7 +424,7 @@ add_instruct(PInfo pi, const char *name, Attr attrs, const char *content) {
 	rb_ivar_set(inst, ox_at_content_id, c);
     } else if (0 != attrs->name) {
         volatile VALUE   ah = rb_hash_new();
-        
+
         for (; 0 != attrs->name; attrs++) {
             volatile VALUE	sym;
 	    VALUE		*slot;
