@@ -5,7 +5,6 @@ module Ox
   # content. The content will be all characters with the exception of the target. If the content follows a regular
   # attribute format then the attributes will be set to the parsed values. If it does not follow the attribute formate
   # then the attributes will be empty.
-
   class Instruct < Node
     include HasAttrs
 
@@ -13,7 +12,7 @@ module Ox
     attr_accessor :content
 
     # Creates a new Instruct with the specified name.
-    # @param [String] name name of the Instruct
+    # - +name+ [String] name of the Instruct
     def initialize(name)
       super
       @attributes = nil
@@ -23,10 +22,9 @@ module Ox
     
     # Returns true if this Object and other are of the same type and have the
     # equivalent value and the equivalent elements otherwise false is returned.
-    # @param [Object] other Object compare _self_ to.
-    # @return [Boolean] true if both Objects are equivalent, otherwise false.
+    # - +other+ [Object] Object compare _self_ to.
+    # *return* [Boolean] true if both Objects are equivalent, otherwise false.
     def eql?(other)
-      return false if (other.nil? or self.class != other.class)
       return false unless super(other)
       return false unless self.attributes == other.attributes
       return false unless self.content == other.content
